@@ -15,6 +15,7 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.util.apllog;
 
+import java.sql.Timestamp;
 import java.text.MessageFormat;
 import java.util.Collections;
 import java.util.Date;
@@ -25,8 +26,9 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.ConfirmConstant;
+import com.clustercontrol.bean.OutputNotifyGroupInfo;
 import com.clustercontrol.bean.PriorityConstant;
-import com.clustercontrol.monitor.message.LogOutputInfo;
+import com.clustercontrol.notify.bean.QueueConstant;
 
 
 
@@ -39,7 +41,7 @@ import com.clustercontrol.monitor.message.LogOutputInfo;
  * 処理します。
  * 
  * AplLogger
- * @version $Revision: 728 $
+ * @version $Revision:2230 $
  * @since 
  */
 public class AplLogger {
@@ -84,7 +86,7 @@ public class AplLogger {
 	 * の３つの状態があります。
 	 * 
 	 * OutPutInfo
-	 * @version $Revision: 728 $
+	 * @version $Revision:2230 $
 	 * @since
 	 */
 	private class OutPutInfo{
@@ -142,7 +144,7 @@ public class AplLogger {
         
         //メッセージ送信クラス初期化
         if( m_sendQueue == null ){
-            m_sendQueue = new SendQueue("queue/clustercontrol/Monitor/EventLog");
+            m_sendQueue = new SendQueue(QueueConstant.QUEUE_NAME_EVENT);
         }
         
         //アプリケーション名取得
@@ -348,38 +350,24 @@ public class AplLogger {
 //    	・メッセージ			:パラメータ、リソースファイル（重要度を除く）
 //    	・オリジナルメッセージ	:パラメータ
 //    	・重要度				:パラメータ、リソースファイル
-//    	・確認済みフラグ		:NO
 //    	・発生日時				:現在日時※メソッド呼び出し時に取得したもの
-//    	・ログ出力フラグ		:true
-//    	・ステータス出力フラグ	:false
-//    	・除外期間（分）		:0
-//    	・除外回数				:0
-//    	・通知情報（送信先）	:なし
-//
-
+//    	・出力日時				:現在日時※イベント出力直前に取得したもの
         
         //メッセージ情報作成
-		LogOutputInfo logOutput = new LogOutputInfo();
-		logOutput.setPluginId(m_pluginID);
-		logOutput.setMonitorId(monitorId);
-		logOutput.setFacilityId(INTERNAL_SCOPE);
-		logOutput.setScopeText(INTERNAL_SCOPE_TEXT);
-		logOutput.setApplication(m_aplName);
-		logOutput.setMessageId(msgId);
-		logOutput.setMessage(msg);
-		logOutput.setMessageOrg(detailMsg == null ? "":detailMsg);
-		logOutput.setPriority(priority);
-		logOutput.setConfirmFlg( ConfirmConstant.booleanToType(false) );
-		logOutput.setGenerationDate(genDate);
-		logOutput.setEventLogFlg(true);
-		logOutput.setStatusInfoFlg(false);
-		logOutput.setExcludePeriod(0);
-		logOutput.setExcludeNumber(0);
-//		logOutput.setAddress(null);
-		
+    	OutputNotifyGroupInfo output = new OutputNotifyGroupInfo();
+		output.setPluginId(m_pluginID);
+		output.setMonitorId(monitorId);
+		output.setFacilityId(INTERNAL_SCOPE);
+		output.setScopeText(INTERNAL_SCOPE_TEXT);
+		output.setApplication(m_aplName);
+		output.setMessageId(msgId);
+		output.setMessage(msg);
+		output.setMessageOrg(detailMsg == null ? "":detailMsg);
+		output.setPriority(priority);
+		output.setGenerationDate(genDate);
 		
         //メッセージ送信
-        return m_sendQueue.put(logOutput);
+        return m_sendQueue.put(output);
     }
 
     /**
