@@ -354,9 +354,25 @@ public class SelectCalendar {
         try {
 			//カレンダ情報を取得
 			CalendarInfoLocal cal = CalendarInfoUtil.getLocalHome().findByPrimaryKey(id);
+			//有効期間（開始）時刻から、その日の00:00:00を取得
+    		Calendar validTimeFromCalendar = Calendar.getInstance();
+    		validTimeFromCalendar.setTime(cal.getValid_time_from());
+    		validTimeFromCalendar.set(Calendar.HOUR_OF_DAY, 0);
+    		validTimeFromCalendar.set(Calendar.MINUTE, 0);
+    		validTimeFromCalendar.set(Calendar.SECOND, 0);
+    		Date validTimeFrom = validTimeFromCalendar.getTime();
+
+			//有効期間（終了）時刻から、その日の23:59:59を取得
+    		Calendar validTimeToCalendar = Calendar.getInstance();
+    		validTimeToCalendar.setTime(cal.getValid_time_to());
+    		validTimeToCalendar.set(Calendar.HOUR_OF_DAY, 23);
+    		validTimeToCalendar.set(Calendar.MINUTE, 59);
+    		validTimeToCalendar.set(Calendar.SECOND, 59);
+    		Date validTimeToDate = validTimeToCalendar.getTime();
+			
 			if(cal != null){
-				if(checkTimestamp.after(cal.getValid_time_from()) && 
-						checkTimestamp.before(cal.getValid_time_to())){
+				if(checkTimestamp.after(validTimeFrom) && 
+						checkTimestamp.before(validTimeToDate)){
 			    	//追加情報を取得
 			        if(isScheduleByAddInfo(id, checkTimestamp)){
 			        	run = Boolean.valueOf(true);
@@ -397,7 +413,12 @@ public class SelectCalendar {
 
 		try {
 			if(id != null && id.length() > 0){
-				Collection ct = CalendarAddInfoUtil.getLocalHome().selectSchdule(id, checkTimestamp);
+		    	// 大元のカレンダ情報（CalendarInfo）の有効期間を取得する
+		    	CalendarInfoLocal calInfo= CalendarInfoUtil.getLocalHome().findByPrimaryKey(id);
+		    	Date mstTimeFrom = calInfo.getValid_time_from(); // 有効期間（開始）
+		    	Date mstTimeTo = calInfo.getValid_time_to(); // 有効期間（終了）
+				
+				Collection ct = CalendarAddInfoUtil.getLocalHome().selectSchdule(id, mstTimeFrom, mstTimeTo, checkTimestamp);
 				if(ct.size() > 0){
 					run = Boolean.valueOf(true);
 				}
@@ -426,6 +447,11 @@ public class SelectCalendar {
      */
 	protected Boolean isScheduleByWeekdayInfo(String id, Date checkTimestamp) throws FinderException, NamingException {
     	Boolean run = Boolean.valueOf(false);
+
+    	// 大元のカレンダ情報（CalendarInfo）の有効期間を取得する
+    	CalendarInfoLocal calInfo= CalendarInfoUtil.getLocalHome().findByPrimaryKey(id);
+    	Date mstTimeFrom = calInfo.getValid_time_from(); // 有効期間（開始）
+    	Date mstTimeTo = calInfo.getValid_time_to(); // 有効期間（終了）
     	
     	Calendar work = Calendar.getInstance();
     	work.setTime(checkTimestamp);
@@ -459,7 +485,27 @@ public class SelectCalendar {
 				        work.set(Calendar.SECOND, baseCalendar.get(Calendar.SECOND));
 				        work.set(Calendar.MILLISECOND,0);
 				        Date end = work.getTime();
-						
+
+				        // 該当曜日の開始時刻が、カレンダの有効期間（終了）よりも未来の場合、
+				        // および、該当曜日の終了時刻が、カレンダの有効期間（開始）よりも昔の場合は、
+				        // 該当曜日設定自体が無効なため、false を返す
+				        if(start.getTime() > mstTimeTo.getTime() ||
+				        		end.getTime() < mstTimeFrom.getTime()){
+				        	return run;
+				        }
+				        
+				        // 該当曜日の開始時刻が、カレンダの有効期間（開始）よりも昔の場合は、
+				        // カレンダの有効期間（開始）時刻からを対象とする
+				        if(start.getTime() < mstTimeFrom.getTime()){
+				        	start = mstTimeFrom;
+				        }
+				        
+				        // 該当曜日の終了時刻が、カレンダの有効期間（終了）よりも未来の場合は、
+				        // カレンダの有効期間（開始）時刻までを対象とする
+				        if(end.getTime() > mstTimeTo.getTime()){
+				        	end = mstTimeTo;
+				        }
+				        
 				        Collection ctNo = CalendarAddInfoUtil.getLocalHome().selectNoSchdule(id, start, end);
 						if(ctNo.size() <= 0){
 							run = Boolean.valueOf(true);
