@@ -15,6 +15,8 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.action;
 
+import java.io.IOException;
+
 import com.clustercontrol.bean.FacilityTreeItem;
 
 /**
@@ -32,6 +34,13 @@ public class GetFacilityTree {
      */
     public FacilityTreeItem getTreeItem(boolean scopeOnly) {
         FacilityTree facilityTree = new FacilityTree();
-        return facilityTree.getTreeItem(scopeOnly);
+        try {
+			return facilityTree.getTreeItem(scopeOnly).deepCopy();
+		} catch (IOException e) {
+			// コピー生成に失敗
+		} catch (ClassNotFoundException e) {
+			// コピー生成に失敗
+		}
+		return null;
     }
 }
\ No newline at end of file
