@@ -550,6 +550,16 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
                 return null;
     	}
         
+    	// 抑制条件は選択されているが、全ての重要度の抑制にチェックが入っていない場合はエラー
+    	if(!this.m_notifyInhibition.m_radioNoInhibition.getSelection() &&
+    			!this.m_checkEventInhibitionInfo.getSelection() && 
+    			!this.m_checkEventInhibitionWarning.getSelection() && 
+    			!this.m_checkEventInhibitionCritical.getSelection() && 
+    			!this.m_checkEventInhibitionUnknown.getSelection()){
+        	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.notify.30"));
+                return null;
+    	}
+    	
     	ArrayList<NotifyInfoDetail> list = new ArrayList<NotifyInfoDetail>();
         
         list = this.createInputDataForEvent(list, PriorityConstant.TYPE_INFO,		this.m_checkEventNormalInfo,	this.m_comboEventNormalInfo,	this.m_checkEventInhibitionInfo,	this.m_comboEventInhibitionInfo);
