@@ -688,6 +688,16 @@ public class NotifyJobCreateDialog extends NotifyBasicCreateDialog {
                 return null;
     	}
     	
+    	// 抑制条件は選択されているが、全ての重要度の抑制にチェックが入っていない場合はエラー
+    	if(!this.m_notifyInhibition.m_radioNoInhibition.getSelection() &&
+    			!this.m_checkInhibitionInfo.getSelection() && 
+    			!this.m_checkInhibitionWarning.getSelection() && 
+    			!this.m_checkInhibitionCritical.getSelection() && 
+    			!this.m_checkInhibitionUnknown.getSelection()){
+        	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.notify.30"));
+                return null;
+    	}
+    	
         ArrayList<NotifyInfoDetail> list = new ArrayList<NotifyInfoDetail>();
                 
         list = this.createInputDataForJob(list, PriorityConstant.TYPE_INFO,			this.m_checkJobRunInfo,			this.m_textJobIdInfo,			this.m_checkInhibitionInfo,			this.m_comboFailurePriorityInfo);
