@@ -506,6 +506,16 @@ public class NotifyMailCreateDialog extends NotifyBasicCreateDialog {
                 return null;
     	}      
 
+    	// 抑制条件は選択されているが、全ての重要度の抑制にチェックが入っていない場合はエラー
+    	if(!this.m_notifyInhibition.m_radioNoInhibition.getSelection() &&
+    			!this.m_checkMailInhibitionInfo.getSelection() && 
+    			!this.m_checkMailInhibitionWarning.getSelection() && 
+    			!this.m_checkMailInhibitionCritical.getSelection() && 
+    			!this.m_checkMailInhibitionUnknown.getSelection()){
+        	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.notify.30"));
+                return null;
+    	}
+    	
         ArrayList<NotifyInfoDetail> list = new ArrayList<NotifyInfoDetail>();
 
         list = this.createInputDataForMail(list, PriorityConstant.TYPE_INFO,	this.m_checkMailNormalInfo,		this.m_textMailAddressInfo,		this.m_checkMailInhibitionInfo);
