@@ -60,6 +60,18 @@ public abstract class ScopeListBaseView extends AutoUpdateView {
 	/** パス文字列を表示するラベル */
 	private Label pathLabel = null;
 	
+	/** ノードをツリーに含めるか？ */
+	protected boolean scopeOnly = false;
+	
+	/** 未登録ノード　スコープをツリーに含めるか？**/
+	protected boolean unregistered = true;
+	
+	/** 内部イベント　スコープをツリーに含めるか？**/
+	protected boolean internal = true;
+	
+	/** リポジトリ情報更新により、表示をリフレッシュするかどうか **/
+	protected boolean topicRefresh = true;
+	
 	// ----- コンストラクタ ----- //
 	
 	/**
@@ -67,6 +79,28 @@ public abstract class ScopeListBaseView extends AutoUpdateView {
 	 */
 	public ScopeListBaseView() {
 		super();
+		
+		this.scopeOnly = false;
+		this.unregistered = true;
+		this.internal = true;
+		this.topicRefresh = true;
+	}
+	
+	/**
+	 * 親のコンストラクタを呼び出します。
+	 * 
+	 * @param scopeOnly スコープのみのスコープツリーとするかどうか
+	 * @param unregistered UNREGISTEREDをスコープツリーに含めるかどうか
+	 * @param internal INTERNALをスコープツリーに含めるかどうか
+	 * @param topicRefresh リポジトリ情報が更新された際に画面リフレッシュするかどうか
+	 */
+	public ScopeListBaseView(boolean scopeOnly ,boolean unregistered, boolean internal, boolean topicRefresh) {
+		super();
+		
+		this.scopeOnly = scopeOnly;
+		this.unregistered = unregistered;
+		this.internal = internal;
+		this.topicRefresh = topicRefresh;
 	}
 	
 	// ----- instance メソッド ----- //
@@ -95,7 +129,7 @@ public abstract class ScopeListBaseView extends AutoUpdateView {
 		this.treeSash.setLayoutData(gridData);
 		
 		// スコープツリー作成
-		this.scopeTreeComposite = new FacilityTreeComposite(treeSash, SWT.NONE);
+		this.scopeTreeComposite = new FacilityTreeComposite(treeSash, SWT.NONE, this.scopeOnly, this.unregistered, this.internal, this.topicRefresh);
 		
 		// 追加コンポジットのベース作成
 		this.baseComposite = new Composite(this.treeSash, SWT.NONE);
