@@ -17,6 +17,8 @@ package com.clustercontrol.commons.quartz;
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
+import java.rmi.RemoteException;
+import java.util.Date;
 import java.util.Properties;
 
 import javax.naming.CompositeName;
@@ -25,12 +27,13 @@ import javax.naming.InitialContext;
 import javax.naming.Name;
 import javax.naming.NamingException;
 
-import org.quartz.Scheduler;
-import org.quartz.SchedulerException;
-import org.quartz.impl.StdSchedulerFactory;
-
 import org.jboss.naming.NonSerializableFactory;
 import org.jboss.system.ServiceMBeanSupport;
+import org.quartz.JobDetail;
+import org.quartz.Scheduler;
+import org.quartz.SchedulerException;
+import org.quartz.Trigger;
+import org.quartz.impl.StdSchedulerFactory;
 
 /**
  * JBoss起動時にQuartzのスケジューラを実行するためのJMXサービスを実装したクラス
@@ -163,6 +166,9 @@ public class CustomQuartzService extends ServiceMBeanSupport implements CustomQu
 		log.info("Start CustomQuartzService(" + jndiName + ")...");
 
 		try {
+			
+			updateStartTime();
+			
 			rebind();
 			
 	        String mode = System.getProperty("hinemos.manager.mode");
@@ -310,4 +316,91 @@ public class CustomQuartzService extends ServiceMBeanSupport implements CustomQu
     		}
     	}
     }
+
+    /**
+     * 
+     * トリガの開始時刻（startDate）を現在時刻に更新するためのメソッド。
+     * JBoss起動時（スケジューラ起動時）にcallされる。
+     * 
+     * スケジューラが一定時間停止してから起動した際に、トリガが複数回実行されるのを回避するために、
+     * スケジューラ起動時にcallする。
+     * 
+     * @throws NamingException
+     * @throws SchedulerException
+     */
+    private void updateStartTime() throws NamingException, SchedulerException {
+    	
+    	//現在時刻を取得
+    	Date now = new Date();
+    	log.debug("set next_fire_time : " + now.getTime());
+    	
+		try {
+			//QuartzのSchedulerを取得
+			Scheduler scheduler = schedulerFactory.getScheduler();
+			String[] triggerGroupNames = scheduler.getTriggerGroupNames();
+			
+			//triggerGroup, triggerNameからトリガを特定
+			for (String triggerGroupName : triggerGroupNames) {
+				String[] triggerNames = scheduler.getTriggerNames(triggerGroupName);
+				
+				for (String triggerName : triggerNames) {
+					
+					log.debug("triggerGroupName / triggerName : " + triggerGroupName + " / " + triggerName);
+					
+					Trigger trigger = scheduler.getTrigger(triggerName, triggerGroupName);
+
+					//TriggerStateの状態確認 for debug
+					if (log.isDebugEnabled() && trigger != null){
+						switch (scheduler.getTriggerState(triggerName, triggerGroupName)) {
+						case Trigger.STATE_BLOCKED:
+							log.debug("TriggerState triggerGroupName / triggerName : " + triggerGroupName + " / " + triggerName + " is STATE_BLOCKED");							
+							break;
+						case Trigger.STATE_COMPLETE:
+							log.debug("TriggerState triggerGroupName / triggerName : " + triggerGroupName + " / " + triggerName + " is STATE_COMPLETE");							
+							break;
+						case Trigger.STATE_ERROR:
+							log.debug("TriggerState triggerGroupName / triggerName : " + triggerGroupName + " / " + triggerName + " is STATE_ERROR");							
+							break;
+						case Trigger.STATE_NONE:
+							log.debug("TriggerState triggerGroupName / triggerName : " + triggerGroupName + " / " + triggerName + " is STATE_NONE");							
+							break;
+						case Trigger.STATE_NORMAL:
+							log.debug("TriggerState triggerGroupName / triggerName : " + triggerGroupName + " / " + triggerName + " is STATE_NORMAL");							
+							break;
+						case Trigger.STATE_PAUSED:
+							log.debug("TriggerState triggerGroupName / triggerName : " + triggerGroupName + " / " + triggerName + " is STATE_PAUSED");							
+							break;
+						default:
+							break;
+						}
+					}
+					
+					// ジョブ実行のためのスケジュール登録の場合は、JBoss再起動前の
+					// 許容時間（org.quartz.jobStore.misfireThresholdで指定した時間 （デフォルト1時間））以内の
+					// ジョブに関しては実行対象とする必要があるため、ここでStartTimeのリセットは行わない。
+					// ここで、ジョブのStartTimeもリセットしてしまうと、HA構成の場合に、
+					// フェイルオーバ中に実行するようにスケジューリングされていたジョブがフェイルオーバ後に実行されなくなる。
+					//
+					// FIXME ここの"JOB"の文字列をQuartzConstantのGROUP_NAMEで参照すると、
+					// HinemosCommonsプロジェクトより先に、JobManagementEJBプロジェクトを
+					// ビルドする必要が生じ、プロジェクト間の参照が循環する可能性があるため、
+					// マイナーバージョンアップでは、参照なしのオンコードとする。
+					if(!"JOB".equals(triggerGroupName)){
+						// トリガがnullで無い、かつ「有効(STATE_NORMAL)」の場合
+						if (trigger != null 
+								&& scheduler.getTriggerState(triggerName, triggerGroupName) == Trigger.STATE_NORMAL) {
+							log.debug("triggerName : " + triggerName + " is not PAUSED");
+							
+							//トリガに開始時刻をセットして再登録する
+							trigger.setStartTime(now);
+							scheduler.rescheduleJob(triggerName, triggerGroupName, trigger);							
+						}
+					}
+				}
+			}
+		} catch (SchedulerException e) {
+			throw e;
+		}
+		
+    }
 }
