@@ -113,6 +113,20 @@ public abstract class JobParamInfoBean implements javax.ejb.EntityBean {
 		return null;
 	}
 	
+	/**
+	 * セッションIDに一致するジョブ変数情報を検索します。
+	 * 
+	 * @param session_id セッションID
+	 * @param job_id ジョブID
+	 * @return プライマリキーのコレクション
+	 * @throws FinderException
+	 * 
+	 * @see com.clustercontrol.jobmanagement.dao.JobParamInfoDAOImpl#findBySessionIdAndJobId(String, String)
+	 */
+	public Collection ejbFindBySessionId(String session_id) throws FinderException {
+		return null;
+	}
+	
 	/**
 	 * セッションIDとジョブIDに一致するジョブ変数情報を検索します。
 	 * 
