@@ -87,6 +87,8 @@ import com.clustercontrol.jobmanagement.ejb.entity.JobStartJobMasterLocal;
 import com.clustercontrol.jobmanagement.ejb.entity.JobStartMasterLocal;
 import com.clustercontrol.jobmanagement.ejb.entity.JobStartTimeInfoLocal;
 import com.clustercontrol.jobmanagement.ejb.entity.JobStartTimeMasterLocal;
+import com.clustercontrol.notify.ejb.session.NotifyControllerLocal;
+import com.clustercontrol.notify.ejb.session.NotifyControllerUtil;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
 import com.clustercontrol.util.Messages;
@@ -95,7 +97,7 @@ import com.clustercontrol.util.PropertyUtil;
 /**
  * ジョブ情報を検索するクラスです。
  *
- * @version 2.4.0
+ * @version 3.0.0
  * @since 1.0.0
  */
 public class SelectJob {
@@ -119,13 +121,13 @@ public class SelectJob {
 		if(m_openForwardFileJob == null){
 			try {
 			    Properties properties = new Properties();
-				String homedir = System.getProperty("jboss.server.home.dir");
-				String propertyFile = homedir + File.separator + "conf" + File.separator + "jobmanagement.properties";
+			    String etcdir = System.getProperty("hinemos.manager.etc.dir");
+				String propertyFile = etcdir + File.separator + "hinemos.properties";
 				
 				// プロパティファイルからキーと値のリストを読み込みます
 				properties.load(new FileInputStream(propertyFile));
 				
-				String mode = properties.getProperty("open.forward.file.job", "false");
+				String mode = properties.getProperty("job.open.forward.file.job", "false");
 				if(mode.equalsIgnoreCase("true")){
 					m_openForwardFileJob = Boolean.valueOf(true);
 				}
@@ -405,6 +407,11 @@ public class SelectJob {
 	        info.setFile(fileInfo);
 	    }
 	    
+		
+		try {
+		
+			NotifyControllerLocal nc = NotifyControllerUtil.getLocalHome().create();
+	 
 	    //通知メッセージを取得
 	    ArrayList<JobNotificationsInfo> noticeList = new ArrayList<JobNotificationsInfo>();
 	    Collection notices = job.getJobNoticeMaster();
@@ -415,11 +422,22 @@ public class SelectJob {
 			    JobNotificationsInfo notificationsInfo = new JobNotificationsInfo();
 			    notificationsInfo.setType(notice.getNotice_type().intValue());
 			    notificationsInfo.setPriority(notice.getPriority().intValue());
-			    notificationsInfo.setNotify_id(notice.getNotify_id());
-			    noticeList.add(notificationsInfo);
+			    notificationsInfo.setNotifyGroupId(notice.getNotifyGroupId());
+			
+			    //正常終了の場合のみ通知をセット
+			    if(notificationsInfo.getType() == EndStatusConstant.TYPE_NORMAL ){
+			    	//通知情報の取得
+			    	notificationsInfo.setNotifyId(nc.getNotifyRelation(notice.getNotifyGroupId()));
+			    }
+				 noticeList.add(notificationsInfo);
+			 
 			}
 			info.setNotifications(noticeList);
+	
 	    }
+		
+		} catch (CreateException e) {
+		}
 	    
 	    //終了状態を取得
 	    ArrayList<JobEndStatusInfo> endList = new ArrayList<JobEndStatusInfo>();
@@ -1544,12 +1562,13 @@ public class SelectJob {
 	 * @return ジョブツリー情報
 	 * @throws FinderException
 	 * @throws NamingException
+	 * @throws CreateException 
 	 * 
 	 * @see com.clustercontrol.jobmanagement.bean.JobInfo
 	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#createSessionJobData(JobInfoLocal)
 	 */
 	@SuppressWarnings("unchecked")
-	public JobTreeItem getSessionJobInfo(String sessionId, String jobId) throws FinderException, NamingException {
+	public JobTreeItem getSessionJobInfo(String sessionId, String jobId) throws FinderException, NamingException, CreateException {
 		//セッションジョブを取得
 		JobSessionJobLocal sessionJob = 
 			JobSessionJobUtil.getLocalHome().findByPrimaryKey(
@@ -1573,11 +1592,12 @@ public class SelectJob {
 	 * @return ジョブ情報
 	 * @throws FinderException
 	 * @throws NamingException
+	 * @throws CreateException 
 	 * 
 	 * @see com.clustercontrol.jobmanagement.bean.JobInfo
 	 */
 	@SuppressWarnings("unchecked")
-	protected JobInfo createSessionJobData(JobInfoLocal job) throws FinderException, NamingException {
+	protected JobInfo createSessionJobData(JobInfoLocal job) throws FinderException, NamingException, CreateException {
 		//JobInfoを作成
 	    JobInfo info = new JobInfo(job.getJob_id(), job.getJob_name(), job.getJob_type().intValue());
 	    
@@ -1738,6 +1758,8 @@ public class SelectJob {
 	    //通知メッセージを取得
 	    ArrayList<JobNotificationsInfo> noticeList = new ArrayList<JobNotificationsInfo>();
 	    Collection notices = job.getJobNoticeInfo();
+	    NotifyControllerLocal nc = NotifyControllerUtil.getLocalHome().create();
+	
 	    if(notices != null){
 	        Iterator itr = notices.iterator();
 			while(itr.hasNext()){
@@ -1745,10 +1767,18 @@ public class SelectJob {
 			    JobNotificationsInfo notificationsInfo = new JobNotificationsInfo();
 			    notificationsInfo.setType(notice.getNotice_type().intValue());
 			    notificationsInfo.setPriority(notice.getPriority().intValue());
-			    notificationsInfo.setNotify_id(notice.getNotify_id());
-			    noticeList.add(notificationsInfo);
+			    notificationsInfo.setNotifyGroupId(notice.getNotifyGroupId());
+			    
+			    //通知タイプが正常の時のみ通知情報を設定する。
+			    if(notificationsInfo.getType() == EndStatusConstant.TYPE_NORMAL){
+			    	notificationsInfo.setNotifyId(nc.getNotifyRelation(notice.getNotifyGroupId()));
+			    }
+			    	noticeList.add(notificationsInfo);
+			    
 			}
 			info.setNotifications(noticeList);
+			
+			
 	    }
 	    
 	    //終了状態を取得
