@@ -46,6 +46,8 @@ public class RecordSetItemComposite extends Composite {
 	private int arrayNum;
 
 	private Group group;
+	
+	private Group groupForm;
 
 	private Button radioButton00;
 
@@ -55,6 +57,10 @@ public class RecordSetItemComposite extends Composite {
 
 	private Button radioButton03;
 
+	private Button radioButton11;
+
+	private Button radioButton12;
+
 	private RealtimeCollectorItemInfo collectorItemInfo = null;
 
 	/**
@@ -76,23 +82,32 @@ public class RecordSetItemComposite extends Composite {
 	public void update(int i) {
 		// 将来はデータ項目を選択可能にすることを視野にいれる。
 		String displayType = null;
-		boolean isRadioButton0 = false;
-		boolean isRadioButton1 = false;
-		boolean isRadioButton2 = false;
-		boolean isRadioButton3 = false;
+		String displayForm = null;
+		boolean isRadioButton00 = false;
+		boolean isRadioButton01 = false;
+		boolean isRadioButton02 = false;
+		boolean isRadioButton03 = false;
+		boolean isRadioButton11 = false;
+		boolean isRadioButton12 = false;
 
 		// 初期化または前回設定の復元
 		displayType = collectorItemInfo.getDisplayTypeForDialog(i);
 		if (displayType.equals("NonDisplay")) {
-			isRadioButton0 = true;
+			isRadioButton00 = true;
 		} else if (displayType.equals("SelectedScope")) {
-			isRadioButton1 = true;
+			isRadioButton01 = true;
 		} else if (displayType.equals("Detail")) {
-			isRadioButton2 = true;
+			isRadioButton02 = true;
 		} else if (displayType.equals("SubScope")) {
-			isRadioButton3 = true;
+			isRadioButton03 = true;
 		}
-
+		displayForm = collectorItemInfo.getDisplayFormForDialog(i);
+		if (displayForm.equals("FormLine")) {
+			isRadioButton11 = true;
+		} else if (displayForm.equals("FormStackArea")) {
+			isRadioButton12 = true;
+		}
+		
 		// グループの設定
 		String itemCode = collectorItemInfo.getItemCodeForDialog(i);
 		group = new Group(this, SWT.NONE);
@@ -119,7 +134,7 @@ public class RecordSetItemComposite extends Composite {
 		for (int j = 0; j < collectorItemInfo.getItemNumForCollector(); j++) {
 			combo.add(CollectorItemCodeFactory.getFullItemName(
 					collectorItemInfo.getItemCodeForCollector(j),
-					collectorItemInfo.getDeviceNameForCollector(j)));
+					collectorItemInfo.getDisplayNameForCollector(j)));
 		}
 
 		int collectorComboSelectIndex = 0;
@@ -127,15 +142,15 @@ public class RecordSetItemComposite extends Composite {
 		// ItemCodeがnull もしくは 空文字の場合、
 		if (itemCode != null && !itemCode.equals("")) {
 
-			String deviceName = collectorItemInfo.getDeviceNameForDialog(i);
+			String displayName = collectorItemInfo.getDisplayNameForDialog(i);
 			boolean isWhile = true;
 			int count = 0;
 			try {
 				while (isWhile) {
 					// ItemCodeとDeviceNameが同様のモノを発見した場合
 					if(collectorItemInfo.getItemCodeForCollector(count).equals(itemCode)){
-						if(collectorItemInfo.getDeviceNameForCollector(count) == (deviceName) 
-								|| collectorItemInfo.getDeviceNameForCollector(count).equals(deviceName)){
+						if(collectorItemInfo.getDisplayNameForCollector(count) == (displayName) 
+								|| collectorItemInfo.getDisplayNameForCollector(count).equals(displayName)){
 							collectorComboSelectIndex = count;
 							break;
 						}	
@@ -184,11 +199,11 @@ public class RecordSetItemComposite extends Composite {
 					}
 				}
 
-				String deviceName = collectorItemInfo
-						.getDeviceNameForCollector(selectionIndex);
+				String displayName = collectorItemInfo
+						.getDisplayNameForCollector(selectionIndex);
 
 				collectorItemInfo.setItemCodeForDialog(k, itemCode);
-				collectorItemInfo.setDeviceNameForDialog(k, deviceName);
+				collectorItemInfo.setDisplayNameForDialog(k, displayName);
 //				collectorItemInfo.setItemIdForDialog(k, Integer
 //						.toString(selectionIndex));
 				collectorItemInfo.setHasDevice(k, true);
@@ -204,7 +219,7 @@ public class RecordSetItemComposite extends Composite {
 		gridData00 = new GridData(GridData.FILL_VERTICAL);
 		gridData00.horizontalSpan = 3; //３列分を占める
 		radioButton00.setLayoutData(gridData00);
-		radioButton00.setSelection(isRadioButton0);
+		radioButton00.setSelection(isRadioButton00);
 		arrayNum = i;
 		radioButton00.addListener(SWT.Selection, new Listener() {
 			// 名前なしクラスのフィールド変数として保持。
@@ -219,7 +234,7 @@ public class RecordSetItemComposite extends Composite {
 		radioButton01.setText(Messages.getString("SCOPE_REPRESENTING_VALUE"));
 		gridData00 = new GridData(GridData.FILL_VERTICAL);
 		radioButton01.setLayoutData(gridData00);
-		radioButton01.setSelection(isRadioButton1);
+		radioButton01.setSelection(isRadioButton01);
 		radioButton01.addListener(SWT.Selection, new Listener() {
 			// 名前なしクラスのフィールド変数として保持。
 			int j = arrayNum;
@@ -234,7 +249,7 @@ public class RecordSetItemComposite extends Composite {
 				.getString("DETAIL_SCOPE_REPRESENTING_VALUE"));
 		gridData00 = new GridData(GridData.FILL_VERTICAL);
 		radioButton02.setLayoutData(gridData00);
-		radioButton02.setSelection(isRadioButton2);
+		radioButton02.setSelection(isRadioButton02);
 		if (!collectorItemInfo.getItemDetailed(i)) { // 詳細表示が可能でない場合.
 			radioButton02.setEnabled(false);
 		}
@@ -251,7 +266,7 @@ public class RecordSetItemComposite extends Composite {
 		radioButton03.setText(Messages.getString("SUB_SCOPE_REP_VAL"));
 		gridData00 = new GridData(GridData.FILL_VERTICAL);
 		radioButton03.setLayoutData(gridData00);
-		radioButton03.setSelection(isRadioButton3);
+		radioButton03.setSelection(isRadioButton03);
 		radioButton03.addListener(SWT.Selection, new Listener() {
 			// 値をオブジェクト内で固定保持するため名前なしクラスのフィールド変数にセットする.
 			int j = arrayNum;
@@ -260,6 +275,46 @@ public class RecordSetItemComposite extends Composite {
 				collectorItemInfo.setDisplayTypeForDialog(j, "SubScope");
 			}
 		});
+		
+		// グループ(グラフの形)の設定
+		groupForm = new Group(group, SWT.NONE);
+		GridData gridDataGroupForm = new GridData(GridData.FILL_HORIZONTAL);
+		gridDataGroupForm.horizontalSpan = 3; //３列分をしめる。
+		groupForm.setLayoutData(gridDataGroupForm);
+		groupForm.setText(Messages.getString("GRAPH_FORM"));
+		GridLayout gridLayout01 = new GridLayout();
+		gridLayout01.numColumns = 3; //３列持つ。現在、「折れ線」と「積み上げ面」の２つ。
+		groupForm.setLayout(gridLayout01);
+		
+		
+		// ラジオボタン(折れ線グラフ)
+		radioButton11 = new Button(groupForm, SWT.RADIO);
+		radioButton11.setText(Messages.getString("FORM_LINE"));
+		gridData00 = new GridData(GridData.FILL_VERTICAL);
+		radioButton11.setLayoutData(gridData00);
+		radioButton11.setSelection(isRadioButton11);
+		radioButton11.addListener(SWT.Selection, new Listener() {
+			// 値をオブジェクト内で固定保持するため名前なしクラスのフィールド変数にセットする.
+			int j = arrayNum;
+
+			public void handleEvent(Event event) {
+				collectorItemInfo.setDisplayFormForDialog(j, "FormLine");
+			}
+		});
+		// ラジオボタン(積み上げ面グラフ)
+		radioButton12 = new Button(groupForm, SWT.RADIO);
+		radioButton12.setText(Messages.getString("FORM_STACK_AREA"));
+		gridData00 = new GridData(GridData.FILL_VERTICAL);
+		radioButton12.setLayoutData(gridData00);
+		radioButton12.setSelection(isRadioButton12);
+		radioButton12.addListener(SWT.Selection, new Listener() {
+			// 値をオブジェクト内で固定保持するため名前なしクラスのフィールド変数にセットする.
+			int j = arrayNum;
+
+			public void handleEvent(Event event) {
+				collectorItemInfo.setDisplayFormForDialog(j, "FormStackArea");
+			}
+		});
 		// ラジオボタン(共通:後処理)
 	}
 
