@@ -49,9 +49,13 @@ public class RealtimeCollectThread extends Thread {
 
 //	private int deviceIndex;
 	
-	private String deviceName;
+//	private String deviceName;
+	
+	private String displayName;
 	
 	private String displayType;
+	
+	private String displayForm;
     
 	private Date timestamp;
 	private int collectTimestampId;
@@ -69,8 +73,10 @@ public class RealtimeCollectThread extends Thread {
     			String itemCode,
 //    			String itemId,
 //    			int deviceIndex,
-    			String deviceName,
+//    			String deviceName,
+    			String displayName,
     			String displayType,
+    			String displayForm,
     			int interval,
     			int requestInterval,
     			String facilityID,
@@ -92,11 +98,17 @@ public class RealtimeCollectThread extends Thread {
 
 //    	this.deviceIndex = deviceIndex;
     	
-    	this.deviceName = deviceName;
-
+//    	this.deviceName = deviceName;
+    	
+    	if (displayName != null) {
+    		this.displayName = displayName;
+		}
     	if (displayType != null) {
             this.displayType = displayType;
     	}
+    	if (displayForm != null) {
+            this.displayForm = displayForm;
+    	}
 //    	if (itemId != null) {
 //            this.itemId = itemId;
 //    	}
@@ -126,7 +138,7 @@ public class RealtimeCollectThread extends Thread {
     	clientRealTimeController.startCollect(
     			timestamp,
     			collectTimestampId,
-    			interval, requestInterval, this, itemCode, deviceName, displayType,
+    			interval, requestInterval, this, itemCode, displayName, displayType, displayForm,
     			// falseは意味なし。
     			facilityID, false,graphComposite); 
     }
@@ -154,9 +166,10 @@ public class RealtimeCollectThread extends Thread {
      * グラフに収集済み性能値を設定する。
      * @param itr
      * @param displayType
+     * @param displayForm
      * @return
      */
-    public boolean setDataList(Iterator<CollectedDataInfo> itr, String displayType) {
+    public boolean setDataList(Iterator<CollectedDataInfo> itr, String displayType, String displayForm) {
 	    // 初期バージョンでは、ファシリティIDがソートされていない場合に配慮し、
 	    // 逐一チェックしてセットしていた。
 	    // 本バージョンでは、ファシリティIDがソートされていることを前堤とした処理方式に変更している。
@@ -179,11 +192,11 @@ public class RealtimeCollectThread extends Thread {
 	    }
 		
 		for (int j=0;j < i; j++) {
-			if (displayType.equals("SelectedScope") || displayType.equals("SubScope")) {
-				graphLineValue = collectedValue[j];
-			} else if (displayType.equals("Detail")) {
+			if (displayForm.equals("FormStackArea")) {
 				graphLineValue = sumOfDataInfoValueSum + collectedValue[j];
 				sumOfDataInfoValueSum = graphLineValue;
+			} else {
+				graphLineValue = collectedValue[j];
 			}
 			// グラフが切り替えられてm_timeseriesが消された場合は処理を停止する。(未実装)
 			if (m_timeseries != null) {
