@@ -18,7 +18,7 @@ package com.clustercontrol.performance.operator;
 /**
  * 	1番目の要素の値を100で割った値を求める（1番目の要素の値を求めることに注意）
  */
-public class DividedBy100 extends SnmpOperator {
+public class DividedBy100 extends Operator {
 	@Override
 	public double calc() throws CollectedDataNotFoundException, InvalidValueException{			
 		return getCurrentMibValue("var0") / 100.0D;			
