@@ -241,9 +241,32 @@ abstract public class Operator {
 					throw new CollectedDataNotFoundException();
 				}
 			}
+			
+			// VMのポーリング結果の場合
 			else {
-				// エラー処理
-				throw new CollectedDataNotFoundException();
+				/*
+				 * getCollectMethod()はVMWARE, XENなどが入っている。
+				 * getCollectMethod()の返り値が、
+				 * select * from cc_vm_solution_mst;
+				 * に含まれている事をチェックする機構を本来は入れるべき。
+				 * 例：含まれていない場合はthrow new CollectedDataNotFound()。
+				 * 今回は割愛。
+				 */
+				try {
+					// entryKeyの最後の一文字が"?"の場合
+					String pollingTarget = data.getPollingTarget() + "." + getDeviceName();
+					
+					// VMの場合は、現在のテーブルと過去のテーブルでentryKeyを変更することができないため、同じentryKeyを与える
+					return getMibValueDiff(data, currentTable, previousTable, 
+							PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget), 
+							PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget));
+				} catch (InvalidValueException e){
+					throw e;
+				} catch (Exception e){
+					m_log.debug(e.getMessage(), e);
+					// エラー処理
+					throw new CollectedDataNotFoundException();
+				}
 			}
 			
 		} else if ("*".equals(targetIndex)){
@@ -388,12 +411,29 @@ abstract public class Operator {
 					throw new CollectedDataNotFoundException();
 				}
 			}
+			
+			// VMのポーリング結果の場合
 			else {
-				// エラー処理
-				throw new CollectedDataNotFoundException();
+				/*
+				 * getCollectMethod()はVMWARE, XENなどが入っている。
+				 * getCollectMethod()の返り値が、
+				 * select * from cc_vm_solution_mst;
+				 * に含まれている事をチェックする機構を本来は入れるべき。
+				 * 例：含まれていない場合はthrow new CollectedDataNotFound()。
+				 * 今回は割愛。
+				 */
+				try {
+					// entryKeyの最後の一文字が"?"の場合
+					String pollingTarget = data.getPollingTarget() + "." + getDeviceName();
+					return getMibValueDouble(table, data, PollerProtocolConstant.getEntryKey(getCollectMethod() ,pollingTarget));
+				} catch (InvalidValueException e){
+					throw e;
+				} catch (Exception e){
+					m_log.debug(e.getMessage(), e);
+					// エラー処理
+					throw new CollectedDataNotFoundException();
+				}
 			}
-			
-			
 		} else if ("*".equals(targetIndex)){
 			try {
 				// entryKeyの最後の一文字が"*"の場合
