@@ -20,6 +20,7 @@ import java.net.UnknownHostException;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.regex.Matcher;
@@ -234,8 +235,10 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 		// node    → IPアドレスとノード名のリスト
 		// target  → nodoのリスト
 		
-		ArrayList hosts     = new ArrayList();
-		ArrayList hostsv6   = new ArrayList();
+//		ArrayList hosts     = new ArrayList();
+//		ArrayList hostsv6   = new ArrayList();
+		HashSet hosts     = new HashSet();
+		HashSet hostsv6   = new HashSet();
 		m_Target = new Hashtable();
 		
 		String facilityId = null;
@@ -275,13 +278,14 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 						
 						if(node[0] != null && !node[0].equals("")){
 							
-							//IPアドレスをArryListに入れていく。
+							//IPアドレスをHashSetに入れていく。
 							hostsv6.add(node[0]);
 						}
 					}else{
 						node[0] = (String)facilityAttrMap.get(FacilityAttributeConstant.IPNETWORKNUMBER);
 						if(node[0] != null && !node[0].equals("")){
-							//IPアドレスをArryListに入れていく。
+							
+							//IPアドレスをHashSetに入れていく。
 							hosts.add(node[0]);
 						}
 					}
@@ -346,16 +350,20 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 	 * @param count      ping回数
 	 * @return (IPアドレス 応答率、平均応答時間)のハッシュテーブル
 	 */
-	private Hashtable wrapUpFping(ArrayList messages,  int count, int version){
+	private Hashtable<String, PingResult> wrapUpFping(ArrayList<String> messages,  int count, int version){
+		
+		Hashtable<String, PingResult> ret = new Hashtable<String, PingResult>();
+		HashMap<String, String> normalMap = new HashMap<String, String>(); //IPアドレス, メッセージ
+		HashMap<String, String> aberrantMap = new HashMap<String, String>(); //IPアドレス, メッセージ
+		HashSet<String> hostSet = new HashSet<String>();
 		
-		Hashtable ret = new Hashtable();
 		/**
 		 * データセットとして必要なものは以下の5つ
 		 * 分割したオリジナルメッセージからデータを作る。
 		 * 
 		 **/
 		String msg;
-		String msgOrg ;
+		String msgOrg;
 		int lost;
 		float average = 0;
 		float reachRatio;
@@ -371,71 +379,155 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 		
 		//fpingの出力を分割するパターン
 		Pattern patternSp = Pattern.compile("(\\s:\\s|\\s)+");
-		Matcher matcher;
+		//正常な出力パターン
+		Pattern patternNormal = Pattern.compile("([0-9]+\\.[0-9]+|-)");
 		
-		for(int index = 0 ; index < messages.size(); index++){
+		//IPアドレス判定用
+		Matcher matcherIp;
+		Matcher matcherValue;
+		
+		String message;
+		
+		/*
+		 * fpingの出力正式は
+		 * 応答がある場合							127.0.0.1 : 0.10 1.23
+		 * 応答がない場合							127.0.0.1 : - -
+		 * その他(複数のIPから応答がある)			127.0.0.1 : duplicate for [0], xx bytes, x.xx ms
+		 * その他(デフォルトGWが設定されていない)	127.0.0.1 : (空白)
+		 * など･･･
+		 * 多岐にわたるため、正常な応答を上記の「応答がある場合」、「応答がない場合」の
+         * 2つに絞り、それ以外のものは、メッセージの余白に追記する。
+		 * さらに、正常以外だった該当のIPアドレスの情報が存在しない場合は、
+		 * 重要度不明で通知する。
+		 */
+		
+		
+		/*
+		 * 取得結果の要素チェック
+		 */
+		Iterator<String> itr = messages.iterator();
+		while(itr.hasNext()) {
 			
-			//fpingの出力正式は　127.0.0.1 : 0.10 1.23
-			matcher = patternIp.matcher((String) messages.get(index));
+			message = itr.next();
 			
-			//出力結果から結果内容をフィルタする。
-			if(matcher.matches()){
+			//IPアドレスの形式が正しい場合は、処理を続行する
+			matcherIp = patternIp.matcher(message);
+			if(matcherIp.matches()){
+				
+				//各IPの結果を要素ごとに確認する
+				String[] strs = patternSp.split(message);
+				
+				//各IPに対する結果を判定
+				boolean isNormal = true;
+				for(int i = 1; i< strs.length; i++) {
+					
+					matcherValue = patternNormal.matcher(strs[i]);
+					if(!matcherValue.matches()){
+						isNormal = false;
+					}
+				}
+				
+				if(isNormal) {
+					normalMap.put(strs[0], message);
+					m_log.debug("wrapUpFping() : normalValue : " + message);
+				}
+				else {
+					// 既に該当するIPアドレスに情報がある場合は、追記する
+					if(aberrantMap.get(strs[0]) != null && !(aberrantMap.get(strs[0])).equals("")){
+						String aberrantMessage = aberrantMap.get(strs[0]);
+						aberrantMessage = aberrantMessage + "\n" + message;
+						aberrantMap.put(strs[0], aberrantMessage);
+					}
+					else {
+						aberrantMap.put(strs[0], message);
+					}
+					m_log.debug("wrapUpFping() : aberrantValue : " + message);
+				}
+				
+				hostSet.add(strs[0]);
+			}
+		}
+		
+		
+		
+		/*
+		 * チェックした内容を結果としてまとめる
+		 */
+		itr = hostSet.iterator();
+		while(itr.hasNext()) {
+			
+			String host = itr.next();
+			String normalMessage = normalMap.get(host);
+			String aberrantMessage = aberrantMap.get(host);
+			
+			if(normalMessage != null && !normalMessage.equals("")) {
 				
 				// String の分割する。
-				String[] strs = patternSp.split((String) messages.get(index));
+				String[] strs = patternSp.split(normalMessage);	
 				
-				/**以下の変数はメッセージを作成するために必要**/
-				float max=0;         //最大応答時間(初期値0秒)
-				float min=Float.MAX_VALUE; //最小応答時間(初期値Floatの最大値)
-				int num=0;         //受信パケット
+				/*以下の変数はメッセージを作成するために必要*/
+				float max = 0;   	      		//最大応答時間(初期値0秒)
+				float min = Float.MAX_VALUE;	//最小応答時間(初期値Floatの最大値)
+				int num = 0;					//受信パケット
 				
 				//収集回数分だけ入っているデータを読み出す。
-				for (int index1=1 ; index1 <=count; index1++ ){
+				for (int i = 1; i <= count; i++ ){
 					
-					if(strs[index1].equals("-")){
+					if(strs[i].equals("-")) {
 						
-					}else{
+						//結果「-」である場合は何もしない
+						
+					} 
+					else {
 						
 						//パケット数はcount up
 						num++; 
 						
 						//最大応答時間のチェックと更新
-						
-						if(max< Float.parseFloat(strs[index1]))
-							max =  Float.parseFloat(strs[index1]);
+						if(max < Float.parseFloat(strs[i])) {
+							max =  Float.parseFloat(strs[i]);
+						}
 						
 						//最小応答時間のチェックと更新
-						if(min > Float.parseFloat(strs[index1]))
-							min =  Float.parseFloat(strs[index1]);
+						if(min > Float.parseFloat(strs[i])) {
+							min =  Float.parseFloat(strs[i]);
+						}
 						
 						//平均応答時間
-						average += Float.parseFloat(strs[index1]);
+						average += Float.parseFloat(strs[i]);
 					}
 				}
 				
-				//平均なので、和を回数で割っておきます。
-				average /= count;
+				//平均なので、和を実行回数で割っておきます。
+				average /= num;
+				
+				
+				/* 
+				 * 出力結果の作成 
+				 */
 				
 				StringBuffer buffer = new StringBuffer();
+				buffer.append("Pinging " + host  + " (" + host + ") .\n\n");
 				
-				buffer.append("Pinging " + strs[0]  + " (" + strs[0] + ") .\n\n");
+				// 受信パケットが0の場合
 				if (num == 0) {
 					//受信パケットが0の時はlost→100 reach→0
 					lost = 100;
-					reachRatio=0;
+					reachRatio = 0;
 					
-					for (int index1=0 ; index1 < count; index1++ )
+					for (int i = 0 ; i < count; i++ )
 						// buffer.append("From " + strs[0] + " icmp_seq="+ index +" Destination Host Unreachable");
-						buffer.append("Reply from " + strs[0] + " icmp_seq="+ index +" Destination Host Unreachable");
+						buffer.append("Reply from " + host + " icmp_seq="+ i +" Destination Host Unreachable\n");
 					
-					buffer.append("\nPing statistics for " + strs[0] + ":\n");
+					buffer.append("\nPing statistics for " + host + ":\n");
 					buffer.append( "Packets: Sent = " + count + ", Received = " + num + ", Lost = " + (count-num) + " (" + lost + "% loss),");
 					
-				} else {
+				} 
+				else {
 					lost = (count - num) * 100 / count;
-					reachRatio = num*100/count;
+					reachRatio = num * 100 / count;
 					
-					buffer.append("\nPing statistics for " + strs[0] + ":\n");
+					buffer.append("\nPing statistics for " + host + ":\n");
 					buffer.append( "Packets: Sent = " + count + ", Received = " + num + ", Lost = " + (count-num) + " (" + lost + "% loss),");
 					buffer.append("Approximate round trip times in milli-seconds:\n");
 					buffer.append("\tMinimum = " + min 
@@ -443,20 +535,50 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 							+ "ms, Average = " + average + "ms\n");
 				}
 				
+				
+				// 異常なメッセージも存在する場合は、msgOrgに追加
+				if(aberrantMessage != null && !aberrantMessage.equals("")) {
+					buffer.append("\n\n" + aberrantMessage + "\n");
+				}
+				
+				
 				msgOrg =buffer.toString();
-				msg= "Packets: Sent = " + count + ", Received = " + num + ", Lost = " + (count-num) + " (" + lost + "% loss)";
+				msg = "Packets: Sent = " + count + ", Received = " + num + ", Lost = " + (count-num) + " (" + lost + "% loss)";
 				
-				PingResult res = new PingResult(strs[0],msg,msgOrg,lost,average, reachRatio);
+				PingResult res = new PingResult(host, msg, msgOrg, lost, average, reachRatio);
 				
-				ret.put(strs[0],res); 
+				ret.put(host, res); 
 				
-				msg="";
-				msgOrg="" ;
-				lost=100;
+				m_log.debug("wrapUpFping() : success msg = " + msg + ", msgOrg = " +msgOrg);
+				
+				msg = "";
+				msgOrg = "" ;
+				lost = 100;
 				average = 0;
-				reachRatio=0;
+				reachRatio = 0;
+				
 			}
+			// 正常なメッセージが存在しない場合
+			else {
+				
+				msg = "Failed to get a value.";
+				msgOrg = "Failed to get a value.";
+				if(aberrantMessage != null && !aberrantMessage.equals("")) {
+					msgOrg = msgOrg + "\n\n" + aberrantMessage;
+				}
+				
+				PingResult res = new PingResult(host, msg, msgOrg, -1, -1, -1);
+				
+				ret.put(host, res);
+				
+				m_log.debug("wrapUpFping() : failure msg = " + msg + ", msgOrg = " +msgOrg);
+				
+				msg = "";
+				msgOrg = "" ;
+			}
+			
 		}
+		
 		return ret;
 	}
 	
@@ -714,9 +836,12 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 						fpingResultSetV6 = wrapUpFping(m_MsgErrV6, m_runCount,6);
 					}
 					
+					//IPv4の情報が存在しない場合は、IPv6の情報で上書きする
 					if( fpingResultSet.size() == 0){
 						fpingResultSet = fpingResultSetV6;
-					}else if(fpingResultSetV6 .size()!= 0){
+					}
+					//IPv4の情報が存在する場合は、IPv6の情報を追加する
+					else if(fpingResultSetV6 .size()!= 0){
 						fpingResultSet.putAll(fpingResultSetV6);
 					}
 					
@@ -741,7 +866,7 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 							
 							if(nodeResult ==null){
 								
-								/**fping失敗で結果がありません。**/
+								/* fping失敗で結果がありません。*/
 								m_log.error("Fping no response.");
 								
 							}else{
@@ -754,7 +879,14 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 								m_messageOrg = (String)nodeResult.getMesseageOrg();
 								
 								// 監視値より判定結果を取得
-								int checkResult = getCheckResult(true);
+								int checkResult;
+								// 値取得に失敗している場合
+								if (m_lost == -1) {
+									checkResult = getCheckResult(false);
+								}
+								else {
+									checkResult = getCheckResult(true);
+								}
 								
 								// 監視単位がスコープとノードの場合、スコープ用の情報を設定
 								if(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock ||
