@@ -31,14 +31,12 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.bean.DataRangeConstant;
-import com.clustercontrol.bean.MonitorBlockConstant;
-import com.clustercontrol.bean.MonitorConstant;
+import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.PortRunCountConstant;
 import com.clustercontrol.bean.PortRunIntervalConstant;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.ProtocolConstant;
 import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.composite.PositiveNumberVerifyListener;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
@@ -49,8 +47,8 @@ import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
 import com.clustercontrol.monitor.run.composite.MonitorBasicScopeComposite;
 import com.clustercontrol.monitor.run.composite.MonitorBlockComposite;
 import com.clustercontrol.monitor.run.composite.MonitorRuleComposite;
-import com.clustercontrol.monitor.run.composite.NumericRunJobComposite;
 import com.clustercontrol.monitor.run.composite.NumericValueInfoComposite;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
 import com.clustercontrol.notify.composite.NotifyInfoComposite;
 import com.clustercontrol.port.action.AddPort;
 import com.clustercontrol.port.action.GetPort;
@@ -61,7 +59,7 @@ import com.clustercontrol.util.Messages;
 /**
  * port監視作成・変更ダイアログクラスです。
  * 
- * @version 2.4.0
+ * @version 3.0.0
  * @since 2.4.0
  */
 public class PortCreateDialog extends CommonDialog {
@@ -119,8 +117,6 @@ public class PortCreateDialog extends CommonDialog {
     /** ジョブ実行 */
     private Button m_checkJobRun = null;
     
-    /** ジョブ実行情報 */
-    private NumericRunJobComposite m_jobRun = null;
     
     /** この設定を有効にする */
     private Button confirmValid = null;
@@ -521,41 +517,6 @@ public class PortCreateDialog extends CommonDialog {
 		gridData.grabExcessHorizontalSpace = true;
 		notifyInfo.setLayoutData(gridData);
 		
-		// ジョブ実行
-        this.m_checkJobRun = new Button(groupNotifyAttribute, SWT.CHECK);
-        gridData = new GridData();
-        gridData.horizontalSpan = 1;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        m_checkJobRun.setLayoutData(gridData);
-        m_checkJobRun.setText(Messages.getString("run") + " : ");
-        m_checkJobRun.addSelectionListener(new SelectionAdapter() {
-            public void widgetSelected(SelectionEvent e) {
-            	m_jobRun.setEnabled(m_checkJobRun.getSelection());
-            }
-        });
-		
-		// ジョブ実行グループ
-        Group groupRunJob = new Group(groupNotifyAttribute, SWT.NONE);
-        layout = new GridLayout(1, true);
-        layout.marginWidth = 5;
-        layout.marginHeight = 5;
-        layout.numColumns = 1;
-        groupRunJob.setLayout(layout);
-        gridData = new GridData();
-        gridData.horizontalSpan = 15;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        groupRunJob.setLayoutData(gridData);
-        
-        // 実行（実行，ジョブID，通知抑制と連動，呼出失敗時）
-		this.m_jobRun = new NumericRunJobComposite(groupRunJob, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = 1;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		m_jobRun.setLayoutData(gridData);
-		
         /*
          * 有効／無効
          */
@@ -661,20 +622,16 @@ public class PortCreateDialog extends CommonDialog {
         // ノード単位の結果判定の定義
         m_numericValueInfo.setInputData(monitor);
     	
-        // 通知情報の属性
-        if (monitor.getNotifyId() != null) {
-        	this.notifyInfo.setText(monitor.getNotifyId());
-        }
+    	
+        //通知情報の設定
+        if(monitor.getNotifyId() != null)
+        this.notifyInfo.setNotify(monitor.getNotifyId());
+        
+        
         if (monitor.getApplication() != null) {
         	this.notifyInfo.setApplication(monitor.getApplication());
         }
-        
-        // ジョブ実行
-        m_checkJobRun.setSelection(YesNoConstant.typeToBoolean(monitor.getJobRun()));
-        
-        // 各重要度のジョブ実行
-        m_jobRun.setInputData(monitor);
-        m_jobRun.setEnabled(YesNoConstant.typeToBoolean(monitor.getJobRun()));
+       
         
         // 有効／無効
         if (monitor.getValid() == ValidConstant.TYPE_VALID) {
@@ -690,7 +647,7 @@ public class PortCreateDialog extends CommonDialog {
     protected MonitorInfo createInputData() {
     	MonitorInfo info = new MonitorInfo();
 
-    	info.setMonitorTypeId(MonitorConstant.STRING_PORT);
+    	info.setMonitorTypeId(HinemosModuleConstant.MONITOR_PORT);
     	info.setMonitorType(MonitorTypeConstant.TYPE_NUMERIC);
     	
     	// 監視基本情報
@@ -707,7 +664,7 @@ public class PortCreateDialog extends CommonDialog {
         
         // 監視条件 port監視情報
         MonitorPortInfo portInfo = new MonitorPortInfo();
-        portInfo.setMonitorTypeId(MonitorConstant.STRING_PORT);
+        portInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_PORT);
         portInfo.setMonitorId(info.getMonitorId());
         /** 監視サービスの選択 */
         if (this.m_radioTCP.getSelection()) {
@@ -800,34 +757,31 @@ public class PortCreateDialog extends CommonDialog {
         	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.51"));
         	return null;
         }
-        
-        // 通知情報の属性
-        if (this.notifyInfo.getText() != null
-                && !"".equals((this.notifyInfo.getText()).trim())) {
-        	info.setNotifyId(notifyInfo.getText());
-        }
-
-        if (this.notifyInfo.getApplication() != null
-                && !"".equals((this.notifyInfo.getApplication()).trim())) {
-        	info.setApplication(notifyInfo.getApplication());
-        }
-        else{
-        	if (this.notifyInfo.getText() != null
-                    && !"".equals((this.notifyInfo.getText()).trim())) {
-            	info.setNotifyId(notifyInfo.getText());
-            	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.10"));
-                return null;
-            }
-        }
+         
+        // 通知関連情報とアプリケーションの設定
+		// 通知グループIDの設定
+		info.setNotifyGroupId(NotifyRelationInfo.createNotifyGroupId(HinemosModuleConstant.MONITOR_PORT, info.getMonitorId()));
+		validateResult = notifyInfo.createInputData(info);
+		if (validateResult != null) {
+			if(validateResult.getID() == null){	// 通知ID警告用出力
+				if(!displayQuestion(validateResult)){
+					validateResult = null;
+					return null;
+				}
+			}
+			else{	// アプリケーション未入力チェック
+				return null;
+			}
+		}  
         
         // ジョブ実行
-        info.setJobRun(YesNoConstant.booleanToType(m_checkJobRun.getSelection()));
+       // info.setJobRun(YesNoConstant.booleanToType(m_checkJobRun.getSelection()));
         
         // 各重要度のジョブ実行
-        validateResult = m_jobRun.createInputData(info);
-        if(validateResult != null){
-        	return null;
-        }
+        //validateResult = m_jobRun.createInputData(info);
+//        if(validateResult != null){
+//        	return null;
+//        }
         
         // 有効/無効
         if (this.confirmValid.getSelection()) {
