@@ -57,6 +57,9 @@ import com.clustercontrol.process.ejb.entity.MonitorProcessPollingMstUtil;
 import com.clustercontrol.process.util.PollingDataManager;
 import com.clustercontrol.process.util.ProcessProperties;
 import com.clustercontrol.process.util.PollingProcConnectionManager;
+import com.clustercontrol.repository.bean.FacilityAttributeConstant;
+import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
+import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
 import com.clustercontrol.sharedtable.DataTable;
 import com.clustercontrol.sharedtable.DataTableNotFoundException;
 import com.clustercontrol.sharedtable.SharedTable;
@@ -815,8 +818,72 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 		HashMap<String, List<String>> map = new HashMap<String, List<String>>();
 		map.put(collectMethod, pollingTargets);
 		
-		// ポーリングを実行（タイムアウト：3000ミリ秒、リトライ1回）
-		return poller.polling(3000, 1, map);
+		Integer timeout = 3000;
+		Integer retryCount = 1;
+		
+		// facilityIdとcollectMethodを基に、タイムアウトとリトライ回数を取得する
+		// 収集方法がSNMPの場合
+		if (collectMethod.equals(PollerProtocolConstant.PROTOCOL_SNMP)) {
+			
+			try {
+				ArrayList<String> attributes = new ArrayList<String>();
+				attributes.add(FacilityAttributeConstant.SNMPTIMEOUT); // タイムアウト
+				attributes.add(FacilityAttributeConstant.SNMPRETRIES); // リトライ回数
+				
+				RepositoryControllerLocal repositoryLocal = RepositoryControllerUtil.getLocalHome().create();
+				HashMap<String,Object> nodeInfo = repositoryLocal.getNodeDetail(facilityId, attributes);
+				
+				Object snmpTimeout = nodeInfo.get(FacilityAttributeConstant.SNMPTIMEOUT);
+				Object snmpRetryCount = nodeInfo.get(FacilityAttributeConstant.SNMPRETRIES);
+				
+				if(snmpTimeout != null) {
+					timeout = (Integer)snmpTimeout;
+				}
+				
+				if(snmpRetryCount != null) {
+					retryCount = (Integer)snmpRetryCount;
+				}
+				
+			} catch (CreateException e) {
+				m_log.error(e.getMessage(), e);
+			} catch (FinderException e) {
+				m_log.error(e.getMessage(), e);
+			}
+			
+		}
+		// 収集方法がWBEMの場合
+		else if (collectMethod.equals(PollerProtocolConstant.PROTOCOL_WBEM)) {
+			try {
+				ArrayList<String> attributes = new ArrayList<String>();
+				attributes.add(FacilityAttributeConstant.WBEMTIMEOUT); // Wbem接続タイムアウト
+				attributes.add(FacilityAttributeConstant.WBEMRETRIES); // Wbem接続リトライ回数
+				
+				RepositoryControllerLocal repositoryLocal = RepositoryControllerUtil.getLocalHome().create();
+				HashMap<String,Object> nodeInfo = repositoryLocal.getNodeDetail(facilityId, attributes);
+				
+				Object wbemTimeout = nodeInfo.get(FacilityAttributeConstant.WBEMTIMEOUT);
+				Object wbemRetryCount = nodeInfo.get(FacilityAttributeConstant.WBEMRETRIES);
+				
+				if(wbemTimeout != null) {
+					timeout = (Integer)wbemTimeout;
+				}
+				
+				if(wbemRetryCount != null) {
+					retryCount = (Integer)wbemRetryCount;
+				}
+				
+			} catch (CreateException e) {
+				m_log.error(e.getMessage(), e);
+			} catch (FinderException e) {
+				m_log.error(e.getMessage(), e);
+			}
+			
+		}
+		
+		m_log.debug("retryPolling() : facilityId : " + facilityId + ", collectMethod : " + collectMethod + ", timeout : " + timeout + ", retryCount : " + retryCount);
+		
+		// ポーリングを実行
+		return poller.polling(timeout, retryCount, map);
 	}
 	
 	
