@@ -28,5 +28,5 @@ package com.clustercontrol.repository.bean;
  */
 public class TopicConstant {
     /** リポジトリ更新用トピック */
-    public static final String TOPIC_NAME_EXECUTE = "topic/clustercontrol/Repository/update";
+    public static final String TOPIC_NAME_EXECUTE = "topic/clustercontrolRepositoryUpdate";
 }
