@@ -31,6 +31,7 @@ import org.apache.commons.logging.LogFactory;
 import com.clustercontrol.accesscontrol.util.LdapConnectionManager;
 import com.clustercontrol.accesscontrol.util.TimeKeeper;
 import com.clustercontrol.accesscontrol.util.TimeKeeperService;
+import com.clustercontrol.repository.bean.DeviceInfoAttributeConstant;
 import com.clustercontrol.repository.bean.FileSystemInfoAttributeConstant;
 import com.clustercontrol.repository.ejb.entity.FileSystemInfoBean;
 import com.clustercontrol.repository.ejb.entity.FileSystemInfoPK;
@@ -412,7 +413,28 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 				
 				//dn設定
 				ejb.setDn(dn.toString());
-	
+				
+				// 各種属性値をセットする
+				if (ejb.getDisplayName() != null) {
+					attrs.put(FileSystemInfoAttributeConstant.DISPLAYNAME, ejb.getDisplayName());
+				}
+				
+				if (ejb.getSnmpOID() != null) {
+					attrs.put(FileSystemInfoAttributeConstant.FILESYSTEMSNMPOID, ejb.getSnmpOID());
+				}
+				
+				if (ejb.getFileSystemMountPoint() != null) {
+					attrs.put(FileSystemInfoAttributeConstant.FILESYSTEMMOUNTPOINT, ejb.getFileSystemMountPoint());
+				}
+				
+				if (ejb.getFileSystemType() != null) {
+					attrs.put(FileSystemInfoAttributeConstant.FILESYSTEMTYPE, ejb.getFileSystemType());
+				}
+				
+				if (ejb.getDescription() != null) {
+					attrs.put(FileSystemInfoAttributeConstant.DESCRIPTION, ejb.getDescription());
+				}
+				
 				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
 				timer = TimeKeeperService.start();
 				
